summaryrefslogtreecommitdiffstats
path: root/kdeui/ktoolbarlabelaction.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:46:43 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:46:43 +0000
commitffe8a83e053396df448e9413828527613ca3bd46 (patch)
treea73d4169e02df4a50f9a12cb165fcd0ab5bac7c6 /kdeui/ktoolbarlabelaction.h
parent682bf3bfdcbcbb1fca85e8a36ed03e062e0555d5 (diff)
downloadtdelibs-ffe8a83e053396df448e9413828527613ca3bd46.tar.gz
tdelibs-ffe8a83e053396df448e9413828527613ca3bd46.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1157647 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdeui/ktoolbarlabelaction.h')
-rw-r--r--kdeui/ktoolbarlabelaction.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/kdeui/ktoolbarlabelaction.h b/kdeui/ktoolbarlabelaction.h
index 926d75c7d..099227981 100644
--- a/kdeui/ktoolbarlabelaction.h
+++ b/kdeui/ktoolbarlabelaction.h
@@ -28,7 +28,7 @@ class QLabel;
* KToolBarLabelAction is a convenience class for displaying a label in a
* toolbar.
*
* It provides easy access to the label's #setBuddy(QWidget*) and #buddy()
* methods and can be used as follows:
*
* \code
@@ -36,10 +36,10 @@ class QLabel;
* KHistoryCombo* findCombo = new KHistoryCombo(true, this);
* KWidgetAction* action
* = new KWidgetAction(findCombo, i18n("F&ind Combo"), Qt::Key_F6, this,
- * SLOT(slotFocus()), actionCollection(), "find_combo");
+ * TQT_SLOT(slotFocus()), actionCollection(), "find_combo");
*
* new KToolBarLabelAction(findCombo, i18n("F&ind "), 0, this,
- * SLOT(slotFocus()), actionCollection(),
+ * TQT_SLOT(slotFocus()), actionCollection(),
* "find_label");
*
* \endcode
@@ -55,13 +55,13 @@ public:
* @param text The label's and the action's text.
* @param cut The action's shortcut.
* @param receiver The SLOT's parent.
- * @param slot The SLOT to invoke to execute this action.
+ * @param slot The TQT_SLOT to invoke to execute this action.
* @param parent This action's parent.
* @param name An internal name for this action.
*/
- KToolBarLabelAction(const QString &text,
+ KToolBarLabelAction(const TQString &text,
const KShortcut &cut,
- const QObject *receiver, const char *slot,
+ const TQObject *receiver, const char *slot,
KActionCollection *parent, const char *name);
/**
* Constructs a toolbar label setting a buddy for the label.
@@ -71,19 +71,19 @@ public:
* @param text The label's and the action's text.
* @param cut The action's shortcut.
* @param receiver The SLOT's parent.
- * @param slot The SLOT to invoke to execute this action.
+ * @param slot The TQT_SLOT to invoke to execute this action.
* @param parent This action's parent.
* @param name An internal name for this action.
*/
- KToolBarLabelAction(QWidget* buddy, const QString &text,
+ KToolBarLabelAction(TQWidget* buddy, const TQString &text,
const KShortcut &cut,
- const QObject *receiver, const char *slot,
+ const TQObject *receiver, const char *slot,
KActionCollection *parent, const char *name);
/**
* Constructs a toolbar label for a label.
*
* You can use this constructor if you want to display a class which is
* derived from QLabel in the toolbar. Note that ownership of the label is
* transferred to the action and the label is deleted when the action is
* deleted. So you shouldn't hold any pointers to the label.
*
@@ -94,35 +94,35 @@ public:
* @param label the label which is displayed in the toolbar.
* @param cut The action's shortcut.
* @param receiver The SLOT's parent.
- * @param slot The SLOT to invoke to execute this action.
+ * @param slot The TQT_SLOT to invoke to execute this action.
* @param parent This action's parent.
* @param name An internal name for this action.
*/
- KToolBarLabelAction(QLabel* label, const KShortcut &cut,
- const QObject *receiver, const char *slot,
+ KToolBarLabelAction(TQLabel* label, const KShortcut &cut,
+ const TQObject *receiver, const char *slot,
KActionCollection* parent, const char *name);
virtual ~KToolBarLabelAction();
/**
* Reimplemented to update both the action's text and the label's text.
*/
- virtual void setText(const QString& text);
+ virtual void setText(const TQString& text);
/**
* Sets the label's buddy to buddy.
*
* See QLabel#setBuddy() for details.
*/
- virtual void setBuddy(QWidget* buddy);
+ virtual void setBuddy(TQWidget* buddy);
/**
* Returns the label's buddy or 0 if no buddy is currently set.
*
* See QLabel#buddy() and QLabel#setBuddy() for more information.
*/
- QWidget* buddy() const;
+ TQWidget* buddy() const;
/**
* Returns the label which is used internally.
*/
- QLabel* label() const;
+ TQLabel* label() const;
protected:
virtual void virtual_hook(int id, void* data);
@@ -28,7 +28,7 @@ class QLabel;
* toolbar.
*
- * It provides easy access to the label's #setBuddy(QWidget*) and #buddy()
+ * It provides easy access to the label's #setBuddy(TQWidget*) and #buddy()
* methods and can be used as follows:
*
@@ -71,19 +71,19 @@ public:
*
* You can use this constructor if you want to display a class which is
- * derived from QLabel in the toolbar. Note that ownership of the label is
+ * derived from TQLabel in the toolbar. Note that ownership of the label is
* transferred to the action and the label is deleted when the action is
* deleted. So you shouldn't hold any pointers to the label.